"use client"
import React, { useEffect, useState } from "react";

import Image from "next/image";
import bg from "@/public/images/auth/bg-2.jpg"
import reg1 from './reg1.svg'
import RegForm from "./Form";
import { Swiper, SwiperSlide } from "swiper/react";
import "swiper/css";
import "swiper/css/navigation";
import "swiper/css/pagination";
import { Autoplay, Navigation, Pagination } from "swiper/modules";
import { getApiData } from "@/Helper/common";
import LayoutLoader from "@/components/layout-loader";

const Home = () => {


  const [data, setData] = useState([]);
  const [themeData, setThemeData] = useState([]);
  const dataDefault = [
    {
      "image": "../img/FORGOT_USERID.png"
    },

  ];

  const [loading, setLoading] = useState(true);

  const fetchData = async () => {
    try {
      setLoading(true);
      const apiResData = await getApiData("admin/getMobileSlider?type=web-user-forgot");
      if (apiResData.error === false) {
        setData(apiResData.result);

      } else {
        setData([])
      }

      const apiResThemeData = await getApiData("web/get-theme-data");
      if (apiResThemeData && apiResThemeData.error === false) {
        setThemeData(apiResThemeData.result);

      } else {
        setThemeData("")
      }

      setLoading(false);

    } catch (error) {
      console.error("Error fetching:", error);
      setLoading(false);
    }
  };


  useEffect(() => {
    fetchData();
  }, []);

  if (loading) {
    return <LayoutLoader />;
  }

  return (

    <div className=" flex items-center min-h-screen  overflow-hidden w-full">
      <div className="grid  grid-cols-2 w-full  justify-center overflow-y-auto p-4">

        <div className="col-span-1 h-full w-full  bg-no-repeat bg-center hidden lg:block rounded-xl"

        >

          {
            data && data.length > 0 ?

              <Swiper
                navigation={{
                  prevEl: ".prev",
                  nextEl: ".next",
                }}
                pagination={{
                  clickable: true,
                }}
                modules={[Navigation, Pagination, Autoplay]}
                loop={true}
                autoplay={{
                  delay: 2500,
                  disableOnInteraction: false,
                }}
                className="w-full h-full rounded-2xl auth-swiper"
                style={{
                  "--swiper-pagination-color": "#fff",
                  "--swiper-pagination-bottom": "40px",
                  "--swiper-pagination-bullet-size": "10px",
                }}
              >
                {

                  data.map((item, index) => (
                    <SwiperSlide key={index}>
                      <div className="w-full h-full flex justify-center items-center">
                        <img src={item.image} width={700} height={200} alt="image" />
                      </div>
                    </SwiperSlide>
                  ))


                }
              </Swiper>


              :

              <Swiper
                navigation={{
                  prevEl: ".prev",
                  nextEl: ".next",
                }}
                pagination={{
                  clickable: true,
                }}
                modules={[Navigation, Pagination, Autoplay]}
                loop={true}
                autoplay={{
                  delay: 2500,
                  disableOnInteraction: false,
                }}
                className="w-full h-full rounded-2xl auth-swiper"
                style={{
                  "--swiper-pagination-color": "#fff",
                  "--swiper-pagination-bottom": "40px",
                  "--swiper-pagination-bullet-size": "10px",
                }}
              >
                {

                  dataDefault.map((item, index) => (
                    <SwiperSlide key={index}>
                      <div className="w-full h-full flex justify-center items-center">
                        <img src={item.image} width={700} height={200} alt="image" />
                      </div>
                    </SwiperSlide>
                  ))


                }
              </Swiper>
          }


        </div>
        <div className="px-4 py-4 flex justify-center items-center  col-span-2 lg:col-span-1">
          <div className="sm:w-[600px] w-full">
            <RegForm themeData={themeData} />
          </div>
        </div>
      </div>
    </div>


  );
};

export default Home;
